@@ -44,69 +44,70 @@
 #include "gtksourcetrace.h"
 
 /**
- * SECTION:buffer
- * @Short_description: Subclass of #GtkTextBuffer
- * @Title: GtkSourceBuffer
- * @See_also: #GtkTextBuffer, #GtkSourceView
+ * GtkSourceBuffer:
  *
- * A #GtkSourceBuffer object is the model for #GtkSourceView widgets.
- * It extends the #GtkTextBuffer class by adding features useful to display
+ * Subclass of [class@Gtk.TextBuffer].
+ *
+ * A `GtkSourceBuffer` object is the model for [class@View] widgets.
+ * It extends the [class@Gtk.TextBuffer] class by adding features useful to display
  * and edit source code such as syntax highlighting and bracket matching.
  *
- * To create a #GtkSourceBuffer use gtk_source_buffer_new() or
- * gtk_source_buffer_new_with_language(). The second form is just a convenience
- * function which allows you to initially set a #GtkSourceLanguage. You can also
- * directly create a #GtkSourceView and get its #GtkSourceBuffer with
- * gtk_text_view_get_buffer().
+ * To create a `GtkSourceBuffer` use [ctor@GtkSource.Buffer.new] or
+ * [ctor@GtkSource.Buffer.new_with_language]. The second form is just a convenience
+ * function which allows you to initially set a [class@Language]. You can also
+ * directly create a [class@View] and get its [class@Buffer] with
+ * [method@Gtk.TextView.get_buffer].
  *
  * The highlighting is enabled by default, but you can disable it with
- * gtk_source_buffer_set_highlight_syntax().
+ * [method@Buffer.set_highlight_syntax].
  *
- * # Context Classes # {#context-classes}
+ * # Context Classes:
  *
  * It is possible to retrieve some information from the syntax highlighting
  * engine. The default context classes that are applied to regions of a
- * #GtkSourceBuffer:
- *  - <emphasis>comment</emphasis>: the region delimits a comment;
- *  - <emphasis>no-spell-check</emphasis>: the region should not be spell checked;
- *  - <emphasis>path</emphasis>: the region delimits a path to a file;
- *  - <emphasis>string</emphasis>: the region delimits a string.
+ * `GtkSourceBuffer`:
+ *
+ *  - **comment**: the region delimits a comment;
+ *  - **no-spell-check**: the region should not be spell checked;
+ *  - **path**: the region delimits a path to a file;
+ *  - **string**: the region delimits a string.
  *
  * Custom language definition files can create their own context classes,
- * since the functions like gtk_source_buffer_iter_has_context_class() take
+ * since the functions like [method@Buffer.iter_has_context_class] take
  * a string parameter as the context class.
  *
- * #GtkSourceBuffer provides an API to access the context classes:
- * gtk_source_buffer_iter_has_context_class(),
- * gtk_source_buffer_get_context_classes_at_iter(),
- * gtk_source_buffer_iter_forward_to_context_class_toggle() and
- * gtk_source_buffer_iter_backward_to_context_class_toggle().
+ * `GtkSourceBuffer` provides an API to access the context classes:
+ * [method@Buffer.iter_has_context_class],
+ * [method@Buffer.get_context_classes_at_iter],
+ * [method@Buffer.iter_forward_to_context_class_toggle] and
+ * [method@Buffer.iter_backward_to_context_class_toggle].
  *
- * And the #GtkSourceBuffer::highlight-updated signal permits to be notified
+ * And the [signal@GtkSource.Buffer::highlight-updated] signal permits to be notified
  * when a context class region changes.
  *
- * Each context class has also an associated #GtkTextTag with the name
- * <emphasis>gtksourceview:context-classes:&lt;name&gt;</emphasis>. For example to
- * retrieve the #GtkTextTag for the string context class, one can write:
- * |[
+ * Each context class has also an associated [class@Gtk.TextTag] with the name
+ * `gtksourceview:context-classes:<name>`. For example to
+ * retrieve the [class@Gtk.TextTag] for the string context class, one can write:
+ * ```c
  * GtkTextTagTable *tag_table;
  * GtkTextTag *tag;
  *
  * tag_table = gtk_text_buffer_get_tag_table (buffer);
  * tag = gtk_text_tag_table_lookup (tag_table, "gtksourceview:context-classes:string");
- * ]|
+ * ```
  *
  * The tag must be used for read-only purposes.
  *
- * Accessing a context class via the associated #GtkTextTag is less
- * convenient than the #GtkSourceBuffer API, because:
+ * Accessing a context class via the associated [class@Gtk.TextTag] is less
+ * convenient than the `GtkSourceBuffer` API, because:
+ *
  *  - The tag doesn't always exist, you need to listen to the
- *    #GtkTextTagTable::tag-added and #GtkTextTagTable::tag-removed signals.
- *  - Instead of the #GtkSourceBuffer::highlight-updated signal, you can listen
- *    to the #GtkTextBuffer::apply-tag and #GtkTextBuffer::remove-tag signals.
+ *    [signal@Gtk.TextTagTable::tag-added] and [signal@Gtk.TextTagTable::tag-removed] signals.
+ *  - Instead of the [signal@GtkSource.Buffer::highlight-updated] signal, you can listen
+ *    to the [signal@Gtk.TextBuffer::apply-tag] and [signal@Gtk.TextBuffer::remove-tag] signals.
  *
  * A possible use-case for accessing a context class via the associated
- * #GtkTextTag is to read the region but without adding a hard dependency on the
+ * [class@Gtk.TextTag] is to read the region but without adding a hard dependency on the
  * GtkSourceView library (for example for a spell-checking library that wants to
  * read the no-spell-check region).
  */
@@ -349,9 +350,7 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * GtkSourceBuffer:implicit-trailing-newline:
 	 *
 	 * Whether the buffer has an implicit trailing newline. See
-	 * gtk_source_buffer_set_implicit_trailing_newline().
-	 *
-	 * Since: 3.14
+	 * [method@Buffer.set_implicit_trailing_newline].
 	 */
 	buffer_properties[PROP_IMPLICIT_TRAILING_NEWLINE] =
 		g_param_spec_boolean ("implicit-trailing-newline",
@@ -369,8 +368,6 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * @buffer: a #GtkSourceBuffer
 	 *
 	 * The "cursor-moved" signal is emitted when then insertion mark has moved.
-	 *
-	 * Since: 5.0
 	 */
 	buffer_signals[CURSOR_MOVED] =
 		g_signal_new_class_handler ("cursor-moved",
@@ -386,7 +383,7 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * @end: the end of the updated region
 	 *
 	 * The ::highlight-updated signal is emitted when the syntax
-	 * highlighting and [context classes][context-classes] are updated in a
+	 * highlighting and [context classes](./class.Buffer.html#context-classes) are updated in a
 	 * certain region of the @buffer.
 	 */
 	buffer_signals[HIGHLIGHT_UPDATED] =
@@ -407,7 +404,7 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	/**
 	 * GtkSourceBuffer::source-mark-updated:
 	 * @buffer: the buffer that received the signal
-	 * @mark: the #GtkSourceMark
+	 * @mark: the [class@Mark]
 	 *
 	 * The ::source-mark-updated signal is emitted each time
 	 * a mark is added to, moved or removed from the @buffer.
@@ -438,9 +435,7 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * The signal is emitted only when the @state changes, typically when
 	 * the cursor moves.
 	 *
-	 * A use-case for this signal is to show messages in a #GtkStatusbar.
-	 *
-	 * Since: 2.12
+	 * A use-case for this signal is to show messages in a [class@Gtk.Statusbar].
 	 */
 	buffer_signals[BRACKET_MATCHED] =
 	    g_signal_new ("bracket-matched",
@@ -630,12 +625,13 @@ gtk_source_buffer_new (GtkTextTagTable *table)
  * gtk_source_buffer_new_with_language:
  * @language: a #GtkSourceLanguage.
  *
- * Creates a new source buffer using the highlighting patterns in
- * @language.  This is equivalent to creating a new source buffer with
- * a new tag table and then calling gtk_source_buffer_set_language().
+ * Creates a new source buffer using the highlighting patterns in `language`.  
+ *
+ * This is equivalent to creating a new source buffer with
+ * a new tag table and then calling [method@Buffer.set_language].
  *
  * Returns: a new source buffer which will highlight text
- * according to the highlighting patterns in @language.
+ * according to the highlighting patterns in `language`.
  */
 GtkSourceBuffer *
 gtk_source_buffer_new_with_language (GtkSourceLanguage *language)
@@ -802,7 +798,7 @@ bracket_pair (gunichar  base_char,
  * by minimizing the damage regions. This results in fewer full-redraws
  * when updating the text marks. To see the difference, compare this to
  * gtk_text_buffer_remove_tag() and enable the "show pixel cache" feature
- * the GTK+ inspector.
+ * the GTK inspector.
  */
 static void
 remove_tag_with_minimal_damage (GtkTextBuffer     *buffer,
@@ -1381,8 +1377,9 @@ gtk_source_buffer_get_highlight_matching_brackets (GtkSourceBuffer *buffer)
  * @buffer: a #GtkSourceBuffer.
  * @highlight: %TRUE if you want matching brackets highlighted.
  *
- * Controls the bracket match highlighting function in the buffer.  If
- * activated, when you position your cursor over a bracket character
+ * Controls the bracket match highlighting function in the buffer. 
+ *
+ * If activated, when you position your cursor over a bracket character
  * (a parenthesis, a square bracket, etc.) the matching opening or
  * closing bracket character will be highlighted.
  */
@@ -1433,11 +1430,10 @@ gtk_source_buffer_get_highlight_syntax (GtkSourceBuffer *buffer)
  * Controls whether syntax is highlighted in the buffer.
  *
  * If @highlight is %TRUE, the text will be highlighted according to the syntax
- * patterns specified in the #GtkSourceLanguage set with
- * gtk_source_buffer_set_language().
+ * patterns specified in the [class@Language] set with [method@Buffer.set_language].
  *
  * If @highlight is %FALSE, syntax highlighting is disabled and all the
- * #GtkTextTag objects that have been added by the syntax highlighting engine
+ * [class@Gtk.TextTag] objects that have been added by the syntax highlighting engine
  * are removed from the buffer.
  */
 void
@@ -1462,11 +1458,11 @@ gtk_source_buffer_set_highlight_syntax (GtkSourceBuffer *buffer,
  * @buffer: a #GtkSourceBuffer.
  * @language: (nullable): a #GtkSourceLanguage to set, or %NULL.
  *
- * Associates a #GtkSourceLanguage with the buffer.
+ * Associates a [class@Language] with the buffer.
  *
- * Note that a #GtkSourceLanguage affects not only the syntax highlighting, but
- * also the [context classes][context-classes]. If you want to disable just the
- * syntax highlighting, see gtk_source_buffer_set_highlight_syntax().
+ * Note that a [class@Language] affects not only the syntax highlighting, but
+ * also the [context classes](./class.Buffer.html#context-classes). If you want to disable just the
+ * syntax highlighting, see [method@Buffer.set_highlight_syntax].
  *
  * The buffer holds a reference to @language.
  */
@@ -1517,11 +1513,12 @@ gtk_source_buffer_set_language (GtkSourceBuffer   *buffer,
  * gtk_source_buffer_get_language:
  * @buffer: a #GtkSourceBuffer.
  *
- * Returns the #GtkSourceLanguage associated with the buffer,
- * see gtk_source_buffer_set_language().  The returned object should not be
- * unreferenced by the user.
+ * Returns the [class@Language] associated with the buffer,
+ * see [method@Buffer.set_language]. 
+ * 
+ * The returned object should not be unreferenced by the user.
  *
- * Returns: (nullable) (transfer none): the #GtkSourceLanguage associated
+ * Returns: (nullable) (transfer none): the [class@Language] associated
  * with the buffer, or %NULL.
  */
 GtkSourceLanguage *
@@ -1609,13 +1606,11 @@ _gtk_source_buffer_has_search_highlights (GtkSourceBuffer *buffer)
  *
  * Forces buffer to analyze and highlight the given area synchronously.
  *
- * <note>
- *   <para>
- *     This is a potentially slow operation and should be used only
- *     when you need to make sure that some text not currently
- *     visible is highlighted, for instance before printing.
- *   </para>
- * </note>
+ * **Note**:
+ *
+ * This is a potentially slow operation and should be used only
+ * when you need to make sure that some text not currently
+ * visible is highlighted, for instance before printing.
  **/
 void
 gtk_source_buffer_ensure_highlight (GtkSourceBuffer   *buffer,
@@ -1631,16 +1626,16 @@ gtk_source_buffer_ensure_highlight (GtkSourceBuffer   *buffer,
  * @buffer: a #GtkSourceBuffer.
  * @scheme: (nullable): a #GtkSourceStyleScheme or %NULL.
  *
- * Sets a #GtkSourceStyleScheme to be used by the buffer and the view.
+ * Sets a [class@StyleScheme] to be used by the buffer and the view.
  *
- * Note that a #GtkSourceStyleScheme affects not only the syntax highlighting,
- * but also other #GtkSourceView features such as highlighting the current line,
+ * Note that a [class@StyleScheme] affects not only the syntax highlighting,
+ * but also other [class@View] features such as highlighting the current line,
  * matching brackets, the line numbers, etc.
  *
  * Instead of setting a %NULL @scheme, it is better to disable syntax
- * highlighting with gtk_source_buffer_set_highlight_syntax(), and setting the
- * #GtkSourceStyleScheme with the "classic" or "tango" ID, because those two
- * style schemes follow more closely the GTK+ theme (for example for the
+ * highlighting with [method@Buffer.set_highlight_syntax], and setting the
+ * [class@StyleScheme] with the "classic" or "tango" ID, because those two
+ * style schemes follow more closely the GTK theme (for example for the
  * background color).
  *
  * The buffer holds a reference to @scheme.
@@ -1671,11 +1666,12 @@ gtk_source_buffer_set_style_scheme (GtkSourceBuffer      *buffer,
  * gtk_source_buffer_get_style_scheme:
  * @buffer: a #GtkSourceBuffer.
  *
- * Returns the #GtkSourceStyleScheme associated with the buffer,
- * see gtk_source_buffer_set_style_scheme().
+ * Returns the [class@StyleScheme] associated with the buffer,
+ * see [method@Buffer.set_style_scheme].
+ *
  * The returned object should not be unreferenced by the user.
  *
- * Returns: (nullable) (transfer none): the #GtkSourceStyleScheme
+ * Returns: (nullable) (transfer none): the [class@StyleScheme]
  * associated with the buffer, or %NULL.
  */
 GtkSourceStyleScheme *
@@ -1770,12 +1766,14 @@ gtk_source_buffer_real_mark_deleted (GtkTextBuffer *buffer,
  * @category: a string defining the mark category.
  * @where: location to place the mark.
  *
- * Creates a source mark in the @buffer of category @category.  A source mark is
- * a #GtkTextMark but organised into categories. Depending on the category
- * a pixbuf can be specified that will be displayed along the line of the mark.
+ * Creates a source mark in the `buffer` of category `category`.  
+ * 
+ * A source mark is a [class@Gtk.TextMark] but organized into categories. 
+ * Depending on the category a pixbuf can be specified that will be displayed 
+ * along the line of the mark.
  *
- * Like a #GtkTextMark, a #GtkSourceMark can be anonymous if the
- * passed @name is %NULL.  Also, the buffer owns the marks so you
+ * Like a [class@Gtk.TextMark], a [class@Mark] can be anonymous if the
+ * passed `name` is %NULL.  Also, the buffer owns the marks so you
  * shouldn't unreference it.
  *
  * Marks always have left gravity and are moved to the beginning of
@@ -1784,9 +1782,7 @@ gtk_source_buffer_real_mark_deleted (GtkTextBuffer *buffer,
  * Typical uses for a source mark are bookmarks, breakpoints, current
  * executing instruction indication in a source file, etc..
  *
- * Returns: (transfer none): a new #GtkSourceMark, owned by the buffer.
- *
- * Since: 2.2
+ * Returns: (transfer none): a new [class@Mark], owned by the buffer.
  */
 GtkSourceMark *
 gtk_source_buffer_create_source_mark (GtkSourceBuffer   *buffer,
@@ -1875,13 +1871,13 @@ _gtk_source_buffer_source_mark_prev (GtkSourceBuffer *buffer,
  * @iter: (inout): an iterator.
  * @category: (nullable): category to search for, or %NULL
  *
- * Moves @iter to the position of the next #GtkSourceMark of the given
- * @category. Returns %TRUE if @iter was moved. If @category is NULL, the
+ * Moves `iter` to the position of the next [class@Mark] of the given
+ * `category`.
+ *
+ * Returns %TRUE if `iter` was moved. If `category` is NULL, the
  * next source mark can be of any category.
  *
- * Returns: whether @iter was moved.
- *
- * Since: 2.2
+ * Returns: whether `iter` was moved.
  */
 gboolean
 gtk_source_buffer_forward_iter_to_source_mark (GtkSourceBuffer *buffer,
@@ -1909,13 +1905,13 @@ gtk_source_buffer_forward_iter_to_source_mark (GtkSourceBuffer *buffer,
  * @iter: (inout): an iterator.
  * @category: (nullable): category to search for, or %NULL
  *
- * Moves @iter to the position of the previous #GtkSourceMark of the given
- * category. Returns %TRUE if @iter was moved. If @category is NULL, the
+ * Moves `iter` to the position of the previous [class@Mark] of the given
+ * category. 
+ *
+ * Returns %TRUE if `iter` was moved. If `category` is NULL, the
  * previous source mark can be of any category.
  *
- * Returns: whether @iter was moved.
- *
- * Since: 2.2
+ * Returns: whether `iter` was moved.
  */
 gboolean
 gtk_source_buffer_backward_iter_to_source_mark (GtkSourceBuffer *buffer,
@@ -1943,13 +1939,12 @@ gtk_source_buffer_backward_iter_to_source_mark (GtkSourceBuffer *buffer,
  * @iter: an iterator.
  * @category: (nullable): category to search for, or %NULL
  *
- * Returns the list of marks of the given category at @iter. If @category
- * is %NULL it returns all marks at @iter.
+ * Returns the list of marks of the given category at @iter. 
+ *
+ * If @category is %NULL it returns all marks at @iter.
  *
  * Returns: (element-type GtkSource.Mark) (transfer container):
  * a newly allocated #GSList.
- *
- * Since: 2.2
  */
 GSList *
 gtk_source_buffer_get_source_marks_at_iter (GtkSourceBuffer *buffer,
@@ -1978,12 +1973,11 @@ gtk_source_buffer_get_source_marks_at_iter (GtkSourceBuffer *buffer,
  * @category: (nullable): category to search for, or %NULL
  *
  * Returns the list of marks of the given category at @line.
+ *
  * If @category is %NULL, all marks at @line are returned.
  *
  * Returns: (element-type GtkSource.Mark) (transfer container):
  * a newly allocated #GSList.
- *
- * Since: 2.2
  */
 GSList *
 gtk_source_buffer_get_source_marks_at_line (GtkSourceBuffer *buffer,
@@ -2025,9 +2019,8 @@ gtk_source_buffer_get_source_marks_at_line (GtkSourceBuffer *buffer,
  * @category: (nullable): category to search for, or %NULL.
  *
  * Remove all marks of @category between @start and @end from the buffer.
- * If @category is NULL, all marks in the range will be removed.
  *
- * Since: 2.2
+ * If @category is NULL, all marks in the range will be removed.
  */
 void
 gtk_source_buffer_remove_source_marks (GtkSourceBuffer   *buffer,
@@ -2100,10 +2093,9 @@ get_context_class_tag (GtkSourceBuffer *buffer,
  *
  * Check if the class @context_class is set on @iter.
  *
- * See the #GtkSourceBuffer description for the list of default context classes.
+ * See the [class@Buffer] description for the list of default context classes.
  *
  * Returns: whether @iter has the context class.
- * Since: 2.10
  */
 gboolean
 gtk_source_buffer_iter_has_context_class (GtkSourceBuffer   *buffer,
@@ -2133,13 +2125,11 @@ gtk_source_buffer_iter_has_context_class (GtkSourceBuffer   *buffer,
  *
  * Get all defined context classes at @iter.
  *
- * See the #GtkSourceBuffer description for the list of default context classes.
+ * See the [class@Buffer] description for the list of default context classes.
  *
  * Returns: (array zero-terminated=1) (transfer full): a new %NULL
  * terminated array of context class names.
  * Use g_strfreev() to free the array if it is no longer needed.
- *
- * Since: 2.10
  */
 gchar **
 gtk_source_buffer_get_context_classes_at_iter (GtkSourceBuffer   *buffer,
@@ -2186,17 +2176,16 @@ gtk_source_buffer_get_context_classes_at_iter (GtkSourceBuffer   *buffer,
  * @iter: (inout): a #GtkTextIter.
  * @context_class: the context class.
  *
- * Moves forward to the next toggle (on or off) of the context class. If no
- * matching context class toggles are found, returns %FALSE, otherwise %TRUE.
+ * Moves forward to the next toggle (on or off) of the context class.
+ *
+ * If no matching context class toggles are found, returns %FALSE, otherwise %TRUE.
  * Does not return toggles located at @iter, only toggles after @iter. Sets
  * @iter to the location of the toggle, or to the end of the buffer if no
  * toggle is found.
  *
- * See the #GtkSourceBuffer description for the list of default context classes.
+ * See the [class@Buffer] description for the list of default context classes.
  *
  * Returns: whether we found a context class toggle after @iter
- *
- * Since: 2.10
  */
 gboolean
 gtk_source_buffer_iter_forward_to_context_class_toggle (GtkSourceBuffer *buffer,
@@ -2225,17 +2214,16 @@ gtk_source_buffer_iter_forward_to_context_class_toggle (GtkSourceBuffer *buffer,
  * @iter: (inout): a #GtkTextIter.
  * @context_class: the context class.
  *
- * Moves backward to the next toggle (on or off) of the context class. If no
- * matching context class toggles are found, returns %FALSE, otherwise %TRUE.
+ * Moves backward to the next toggle (on or off) of the context class.
+ *
+ * If no matching context class toggles are found, returns %FALSE, otherwise %TRUE.
  * Does not return toggles located at @iter, only toggles after @iter. Sets
  * @iter to the location of the toggle, or to the end of the buffer if no
  * toggle is found.
  *
- * See the #GtkSourceBuffer description for the list of default context classes.
+ * See the [class@Buffer] description for the list of default context classes.
  *
  * Returns: whether we found a context class toggle before @iter
- *
- * Since: 2.10
  */
 gboolean
 gtk_source_buffer_iter_backward_to_context_class_toggle (GtkSourceBuffer *buffer,
@@ -2486,7 +2474,8 @@ do_title_case (GtkTextBuffer     *buffer,
  *
  * Changes the case of the text between the specified iterators.
  *
- * Since: 3.12
+ * Since 5.4, this function will update the position of `start` and
+ * `end` to surround the modified text.
  */
 void
 gtk_source_buffer_change_case (GtkSourceBuffer         *buffer,
@@ -2532,6 +2521,10 @@ gtk_source_buffer_change_case (GtkSourceBuffer         *buffer,
 	gtk_text_buffer_insert (text_buffer, start, new_text, -1);
 	gtk_text_buffer_end_user_action (text_buffer);
 
+        /* Leave @start and @end in valid positions around the text */
+	*end = *start;
+	gtk_text_iter_backward_chars (start, g_utf8_strlen (new_text, -1));
+
 	g_free (new_text);
 }
 
@@ -2570,8 +2563,6 @@ move_to_line_text_end(GtkTextIter *iter)
  * @end: a #GtkTextIter.
  *
  * Joins the lines of text between the specified iterators.
- *
- * Since: 3.16
  */
 void
 gtk_source_buffer_join_lines (GtkSourceBuffer *buffer,
@@ -2687,8 +2678,6 @@ compare_line_reversed (gconstpointer aptr,
  * @column: sort considering the text starting at the given column
  *
  * Sort the lines of text between the specified iterators.
- *
- * Since: 3.18
  */
 void
 gtk_source_buffer_sort_lines (GtkSourceBuffer    *buffer,
@@ -2939,21 +2928,19 @@ _gtk_source_buffer_has_invalid_chars (GtkSourceBuffer *buffer)
  *
  * Sets whether the @buffer has an implicit trailing newline.
  *
- * If an explicit trailing newline is present in a #GtkTextBuffer, #GtkTextView
+ * If an explicit trailing newline is present in a [class@Gtk.TextBuffer], [class@Gtk.TextView]
  * shows it as an empty line. This is generally not what the user expects.
  *
  * If @implicit_trailing_newline is %TRUE (the default value):
- *  - when a #GtkSourceFileLoader loads the content of a file into the @buffer,
+ *  - when a [class@FileLoader] loads the content of a file into the @buffer,
  *    the trailing newline (if present in the file) is not inserted into the
  *    @buffer.
- *  - when a #GtkSourceFileSaver saves the content of the @buffer into a file, a
+ *  - when a [class@FileSaver] saves the content of the @buffer into a file, a
  *    trailing newline is added to the file.
  *
  * On the other hand, if @implicit_trailing_newline is %FALSE, the file's
  * content is not modified when loaded into the @buffer, and the @buffer's
  * content is not modified when saved into a file.
- *
- * Since: 3.14
  */
 void
 gtk_source_buffer_set_implicit_trailing_newline (GtkSourceBuffer *buffer,
@@ -2977,7 +2964,6 @@ gtk_source_buffer_set_implicit_trailing_newline (GtkSourceBuffer *buffer,
  * @buffer: a #GtkSourceBuffer.
  *
  * Returns: whether the @buffer has an implicit trailing newline.
- * Since: 3.14
  */
 gboolean
 gtk_source_buffer_get_implicit_trailing_newline (GtkSourceBuffer *buffer)
@@ -2996,24 +2982,23 @@ gtk_source_buffer_get_implicit_trailing_newline (GtkSourceBuffer *buffer)
  * @first_property_name: (nullable): name of first property to set, or %NULL
  * @...: %NULL-terminated list of property names and values
  *
- * In short, this is the same function as gtk_text_buffer_create_tag(), but
- * instead of creating a #GtkTextTag, this function creates a #GtkSourceTag.
+ * In short, this is the same function as [method@Gtk.TextBuffer.create_tag] but
+ * instead of creating a [class@Gtk.TextTag], this function creates a [class@Tag].
  *
- * This function creates a #GtkSourceTag and adds it to the tag table for
- * @buffer.  Equivalent to calling gtk_text_tag_new() and then adding the tag to
+ * This function creates a [class@Tag] and adds it to the tag table for
+ * `buffer`.  Equivalent to calling [ctor@Gtk.TextTag.new] and then adding the tag to
  * the buffer’s tag table. The returned tag is owned by the buffer’s tag table,
  * so the ref count will be equal to one.
  *
- * If @tag_name is %NULL, the tag is anonymous.
+ * If `tag_name` is %NULL, the tag is anonymous.
  *
- * If @tag_name is non-%NULL, a tag called @tag_name must not already
+ * If `tag_name` is non-%NULL, a tag called `tag_name` must not already
  * exist in the tag table for this buffer.
  *
- * The @first_property_name argument and subsequent arguments are a list
- * of properties to set on the tag, as with g_object_set().
+ * The `first_property_name` argument and subsequent arguments are a list
+ * of properties to set on the tag, as with [method@GObject.Object.set].
  *
- * Returns: (transfer none): a new #GtkSourceTag.
- * Since: 3.20
+ * Returns: (transfer none): a new [class@Tag].
  */
 GtkTextTag *
 gtk_source_buffer_create_source_tag (GtkSourceBuffer *buffer,
