@@ -31,24 +31,23 @@
 #include "gtksourcegutterrenderer-private.h"
 
 /**
- * SECTION:gutter
- * @Short_description: Gutter object for GtkSourceView
- * @Title: GtkSourceGutter
- * @See_also: #GtkSourceView, #GtkSourceMark
+ * GtkSourceGutter:
  *
- * The #GtkSourceGutter object represents the left or right gutter of the text
- * view. It is used by #GtkSourceView to draw the line numbers and
- * #GtkSourceMark<!-- -->s that might be present on a line. By packing
- * additional #GtkSourceGutterRenderer objects in the gutter, you can extend the
+ * Gutter object for [class@View].
+ *
+ * The `GtkSourceGutter` object represents the left or right gutter of the text
+ * view. It is used by [class@View] to draw the line numbers and
+ * [class@Mark]s that might be present on a line. By packing
+ * additional [class@GutterRenderer] objects in the gutter, you can extend the
  * gutter with your own custom drawings.
  *
- * To get a #GtkSourceGutter, use the gtk_source_view_get_gutter() function.
+ * To get a `GtkSourceGutter`, use the [method@View.get_gutter] function.
  *
- * The gutter works very much the same way as cells rendered in a #GtkTreeView.
+ * The gutter works very much the same way as cells rendered in a [class@Gtk.TreeView].
  * The concept is similar, with the exception that the gutter does not have an
- * underlying #GtkTreeModel. The builtin line number renderer is at position
- * #GTK_SOURCE_VIEW_GUTTER_POSITION_LINES (-30) and the marks renderer is at
- * #GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS (-20). The gutter sorts the renderers
+ * underlying [iface@Gtk.TreeModel]. The builtin line number renderer is at position
+ * %GTK_SOURCE_VIEW_GUTTER_POSITION_LINES (-30) and the marks renderer is at
+ * %GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS (-20). The gutter sorts the renderers
  * in ascending order, from left to right. So the marks are displayed on the
  * right of the line numbers.
  */
@@ -515,8 +514,6 @@ _gtk_source_gutter_new (GtkTextWindowType  type,
  * @gutter: a #GtkSourceGutter.
  *
  * Returns: (transfer none): the associated #GtkSourceView.
- *
- * Since: 3.24
  */
 GtkSourceView *
 gtk_source_gutter_get_view (GtkSourceGutter *gutter)
@@ -537,9 +534,6 @@ gtk_source_gutter_get_view (GtkSourceGutter *gutter)
  * @renderer cannot be already inserted to another gutter.
  *
  * Returns: %TRUE if operation succeeded. Otherwise %FALSE.
- *
- * Since: 3.0
- *
  **/
 gboolean
 gtk_source_gutter_insert (GtkSourceGutter         *gutter,
@@ -637,8 +631,6 @@ gtk_source_gutter_remove (GtkSourceGutter         *gutter,
  * @position: the new renderer position.
  *
  * Reorders @renderer in @gutter to new @position.
- *
- * Since: 2.8
  */
 void
 gtk_source_gutter_reorder (GtkSourceGutter         *gutter,
@@ -706,10 +698,11 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 {
 	GtkSourceGutter *gutter = GTK_SOURCE_GUTTER (widget);
 	GtkTextView *text_view = GTK_TEXT_VIEW (gutter->view);
+	GtkTextBuffer *buffer;
 	const GList *list;
 	GdkRectangle visible_rect;
-	GtkTextIter begin;
-	GtkTextIter end;
+	GtkTextIter begin, end;
+	GtkTextIter cur, sel;
 	gboolean needs_wrap_first = FALSE;
 	gboolean needs_wrap_last = FALSE;
 
@@ -720,6 +713,8 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 		return;
 	}
 
+	buffer = gtk_text_view_get_buffer (text_view);
+
 	gtk_text_view_get_visible_rect (text_view, &visible_rect);
 	gtk_text_view_get_iter_at_location (text_view, &begin,
 	                                    visible_rect.x, visible_rect.y);
@@ -740,18 +735,21 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 	                                              needs_wrap_last);
 
 	/* Draw the current-line highlight if necessary */
-	if (gtk_source_view_get_highlight_current_line (gutter->view))
+	if (gtk_source_view_get_highlight_current_line (gutter->view) &&
+	    !gtk_text_buffer_get_selection_bounds (buffer, &cur, &sel))
 	{
+		GdkRGBA highlight;
 		guint cursor_line;
 
 		cursor_line = _gtk_source_gutter_lines_get_cursor_line (gutter->lines);
 
 		if (cursor_line >= gtk_source_gutter_lines_get_first (gutter->lines) &&
-		    cursor_line <= gtk_source_gutter_lines_get_last (gutter->lines))
+		    cursor_line <= gtk_source_gutter_lines_get_last (gutter->lines) &&
+		    _gtk_source_view_get_current_line_number_background (gutter->view, &highlight))
 		{
-			GdkRGBA highlight;
-			gint y;
-			gint height;
+			int width = gtk_widget_get_width (widget);
+			int height;
+			int y;
 
 			gtk_source_gutter_lines_get_line_yrange (gutter->lines,
 			                                         cursor_line,
@@ -759,14 +757,9 @@ gtk_source_gutter_snapshot (GtkWidget   *widget,
 			                                         &y,
 			                                         &height);
 
-			if (_gtk_source_view_get_current_line_number_background (gutter->view, &highlight))
-			{
-				int width = gtk_widget_get_width (widget);
-
-				gtk_snapshot_append_color (snapshot,
-				                           &highlight,
-				                           &GRAPHENE_RECT_INIT (0, y, width, height));
-			}
+			gtk_snapshot_append_color (snapshot,
+			                           &highlight,
+			                           &GRAPHENE_RECT_INIT (0, y, width, height));
 		}
 	}
 
