@@ -39,31 +39,30 @@
 #define DRAG_THRESHOLD      5.0
 
 /**
- * SECTION:map
- * @Short_description: Widget that displays a map for a specific #GtkSourceView
- * @Title: GtkSourceMap
- * @See_also: #GtkSourceView
+ * GtkSourceMap:
  *
- * #GtkSourceMap is a widget that maps the content of a #GtkSourceView into
+ * Widget that displays a map for a specific [class@View].
+ *
+ * `GtkSourceMap` is a widget that maps the content of a [class@View] into
  * a smaller view so the user can have a quick overview of the whole document.
  *
- * This works by connecting a #GtkSourceView to to the #GtkSourceMap using
- * the #GtkSourceMap:view property or gtk_source_map_set_view().
+ * This works by connecting a [class@View] to to the `GtkSourceMap` using
+ * the [property@Map:view] property or [method@Map.set_view].
  *
- * #GtkSourceMap is a #GtkSourceView object. This means that you can add a
- * #GtkSourceGutterRenderer to a gutter in the same way you would for a
- * #GtkSourceView. One example might be a #GtkSourceGutterRenderer that shows
+ * `GtkSourceMap` is a [class@View] object. This means that you can add a
+ * [class@GutterRenderer] to a gutter in the same way you would for a
+ * [class@View]. One example might be a [class@GutterRenderer] that shows
  * which lines have changed in the document.
  *
- * Additionally, it is desirable to match the font of the #GtkSourceMap and
- * the #GtkSourceView used for editing. Therefore, #GtkSourceMap:font-desc
+ * Additionally, it is desirable to match the font of the `GtkSourceMap` and
+ * the [class@View] used for editing. Therefore, [property@Map:font-desc]
  * should be used to set the target font. You will need to adjust this to the
  * desired font size for the map. A 1pt font generally seems to be an
  * appropriate font size. "Monospace 1" is the default. See
- * pango_font_description_set_size() for how to alter the size of an existing
- * #PangoFontDescription.
+ * [method@Pango.FontDescription.set_size] for how to alter the size of an existing
+ * [struct@Pango.FontDescription].
  *
- * When FontConfig is available, #GtkSourceMap will try to use a bundled
+ * When FontConfig is available, `GtkSourceMap` will try to use a bundled
  * "block" font to make the map more legible.
  */
 
@@ -246,7 +245,7 @@ load_override_font (GtkSourceMap *map)
 	font_map = pango_cairo_font_map_new_for_font_type (CAIRO_FONT_TYPE_FT);
 	pango_fc_font_map_set_config (PANGO_FC_FONT_MAP (font_map), map_font_config);
 	gtk_widget_set_font_map (GTK_WIDGET (map), font_map);
-	font_desc = pango_font_description_from_string ("BuilderBlocks 2");
+	font_desc = pango_font_description_from_string ("BuilderBlocks");
 
 	g_assert (map_font_config != NULL);
 	g_assert (font_map != NULL);
@@ -260,12 +259,14 @@ load_override_font (GtkSourceMap *map)
 #endif
 
 static void
-update_slider_position (GtkSourceMap *map)
+get_slider_position (GtkSourceMap *map,
+                     int           width,
+                     int           height,
+                     GdkRectangle *slider_area)
 {
 	GtkSourceMapPrivate *priv = gtk_source_map_get_instance_private (map);
-	GdkRectangle them_visible_rect;
+	GdkRectangle them_visible_rect, us_visible_rect;
 	GdkRectangle us_alloc;
-	GdkRectangle slider_area;
 	GtkStyleContext *style_context;
 	GtkTextBuffer *buffer;
 	GtkTextIter end_iter;
@@ -292,25 +293,15 @@ update_slider_position (GtkSourceMap *map)
 	them_height = end_rect.y + end_rect.height;
 
 	gtk_text_view_get_visible_rect (GTK_TEXT_VIEW (priv->view), &them_visible_rect);
+	gtk_text_view_get_visible_rect (GTK_TEXT_VIEW (map), &us_visible_rect);
 
-	slider_area.x = 0;
-	slider_area.width = us_alloc.width - border.left - border.right;
-	slider_area.height = 100;
-	slider_area.y = (double)them_visible_rect.y / (double)them_height * (double)us_height;
-	slider_area.height = ((double)(them_visible_rect.y + them_visible_rect.height) / (double)them_height * (double)us_height) - slider_area.y;
+	slider_area->x = 0;
+	slider_area->width = us_alloc.width - border.left - border.right;
+	slider_area->height = 100;
+	slider_area->y = (double)them_visible_rect.y / (double)them_height * (double)us_height;
+	slider_area->height = ((double)(them_visible_rect.y + them_visible_rect.height) / (double)them_height * (double)us_height) - slider_area->y;
 
-	if (memcmp (&slider_area, &priv->slider_area, sizeof slider_area) != 0)
-	{
-		priv->slider_area = slider_area;
-		gtk_widget_set_size_request (GTK_WIDGET (priv->slider),
-		                             MAX (0, slider_area.width),
-		                             MAX (0, slider_area.height));
-		gtk_text_view_move_overlay (GTK_TEXT_VIEW (map),
-		                            GTK_WIDGET (priv->slider),
-		                            slider_area.x,
-		                            slider_area.y);
-		gtk_widget_queue_allocate (GTK_WIDGET (map));
-	}
+	slider_area->y -= us_visible_rect.y;
 }
 
 static void
@@ -409,7 +400,7 @@ gtk_source_map_rebuild_css (GtkSourceMap *map)
 
 		if (_gtk_source_view_get_current_line_background (priv->view, &bg))
 		{
-			bg.alpha = 0.3;
+			bg.alpha = 1.0;
 			background = gdk_rgba_to_string (&bg);
 		}
 	}
@@ -418,6 +409,8 @@ gtk_source_map_rebuild_css (GtkSourceMap *map)
 
 	if (background != NULL)
 	{
+		GdkRGBA parsed;
+
 		if (foreground == NULL)
 		{
 			GtkStyleContext *style_context;
@@ -428,10 +421,17 @@ gtk_source_map_rebuild_css (GtkSourceMap *map)
 			foreground = gdk_rgba_to_string (&color);
 		}
 
+		if (gdk_rgba_parse (&parsed, background))
+		{
+			if (parsed.alpha < 1.0)
+			{
+				parsed.alpha = 1.0;
+				g_free (background);
+				background = gdk_rgba_to_string (&parsed);
+			}
+		}
+
 		g_string_append_printf (gstr,
-		                        "textview.source-map {"
-		                        " color: mix(%s,%s,.25);"
-		                        "}\n"
 		                        "slider {"
 		                        " background-color: alpha(%s,.25);"
 		                        " transition-duration: 300ms;"
@@ -442,7 +442,6 @@ gtk_source_map_rebuild_css (GtkSourceMap *map)
 		                        "slider.dragging:hover {"
 		                        " background-color: alpha(%s,.5);"
 		                        "}\n",
-					foreground, background,
 		                        background, background, background);
 	}
 
@@ -504,7 +503,7 @@ view_vadj_value_changed (GtkSourceMap  *map,
                          GtkAdjustment *vadj)
 {
 	update_child_vadjustment (map);
-	update_slider_position (map);
+	gtk_widget_queue_allocate (GTK_WIDGET (map));
 }
 
 static void
@@ -512,7 +511,7 @@ view_vadj_notify_upper (GtkSourceMap  *map,
                         GParamSpec    *pspec,
                         GtkAdjustment *vadj)
 {
-	update_slider_position (map);
+	gtk_widget_queue_allocate (GTK_WIDGET (map));
 }
 
 static void
@@ -605,6 +604,11 @@ gtk_source_map_set_font_desc (GtkSourceMap               *map,
 		if (font_desc)
 		{
 			priv->font_desc = pango_font_description_copy (font_desc);
+
+			if ((pango_font_description_get_set_fields (priv->font_desc) & PANGO_FONT_MASK_SIZE) == 0)
+			{
+				pango_font_description_set_size (priv->font_desc, 1.75 * PANGO_SCALE);
+			}
 		}
 	}
 
@@ -858,6 +862,12 @@ gtk_source_map_dispose (GObject *object)
 	g_clear_object (&priv->css_provider);
 	g_clear_pointer (&priv->font_desc, pango_font_description_free);
 
+	if (priv->slider)
+	{
+		gtk_widget_unparent (GTK_WIDGET (priv->slider));
+		priv->slider = NULL;
+	}
+
 	G_OBJECT_CLASS (gtk_source_map_parent_class)->dispose (object);
 }
 
@@ -1149,12 +1159,50 @@ gtk_source_map_css_changed (GtkWidget         *widget,
 #endif
 }
 
+static void
+gtk_source_map_size_allocate (GtkWidget *widget,
+                              int        width,
+                              int        height,
+                              int        baseline)
+{
+	GtkSourceMap *map = (GtkSourceMap *)widget;
+	GtkSourceMapPrivate *priv = gtk_source_map_get_instance_private (map);
+	GdkRectangle area;
+	int min, nat;
+
+	g_assert (GTK_SOURCE_IS_MAP (map));
+
+	GTK_WIDGET_CLASS (gtk_source_map_parent_class)->size_allocate (widget, width, height, baseline);
+
+	get_slider_position (map, width, height, &area);
+	gtk_widget_measure (GTK_WIDGET (priv->slider),
+	                    GTK_ORIENTATION_VERTICAL,
+			    width, &min, &nat, NULL, NULL);
+	area.height = MAX (nat, area.height);
+	gtk_widget_size_allocate (GTK_WIDGET (priv->slider), &area, -1);
+}
+
+static void
+gtk_source_map_snapshot (GtkWidget   *widget,
+                         GtkSnapshot *snapshot)
+{
+	GtkSourceMap *map = (GtkSourceMap *)widget;
+	GtkSourceMapPrivate *priv = gtk_source_map_get_instance_private (map);
+
+	g_assert (GTK_IS_WIDGET (widget));
+	g_assert (GTK_IS_SNAPSHOT (snapshot));
+
+	GTK_WIDGET_CLASS (gtk_source_map_parent_class)->snapshot (widget, snapshot);
+
+	gtk_widget_snapshot_child (GTK_WIDGET (map), GTK_WIDGET (priv->slider), snapshot);
+}
+
 static void
 gtk_source_map_constructed (GObject *object)
 {
 	G_OBJECT_CLASS (gtk_source_map_parent_class)->constructed (object);
 
-#ifdef ENABLE_FONT_CONFIG
+#if ENABLE_FONT_CONFIG
 	load_override_font (GTK_SOURCE_MAP (object));
 #endif
 }
@@ -1177,6 +1225,8 @@ gtk_source_map_class_init (GtkSourceMapClass *klass)
 	widget_class->state_flags_changed = gtk_source_map_state_flags_changed;
 	widget_class->realize = gtk_source_map_realize;
 	widget_class->css_changed = gtk_source_map_css_changed;
+	widget_class->size_allocate = gtk_source_map_size_allocate;
+	widget_class->snapshot = gtk_source_map_snapshot;
 
 	text_view_class->snapshot_layer = gtk_source_map_snapshot_layer;
 
@@ -1208,12 +1258,14 @@ gtk_source_map_init (GtkSourceMap *map)
 
 	priv = gtk_source_map_get_instance_private (map);
 
+	gtk_widget_add_css_class (GTK_WIDGET (map), "GtkSourceMap");
+
 	priv->css_provider = gtk_css_provider_new ();
         priv->slider = g_object_new (GTK_SOURCE_TYPE_MAP_SLIDER,
 				     "width-request", 1,
 				     "height-request", 1,
 				     NULL);
-        gtk_text_view_add_overlay (GTK_TEXT_VIEW (map), GTK_WIDGET (priv->slider), 0, 0);
+	gtk_widget_set_parent (GTK_WIDGET (priv->slider), GTK_WIDGET (map));
 
 	gtk_style_context_add_provider (gtk_widget_get_style_context (GTK_WIDGET (map)),
 	                                GTK_STYLE_PROVIDER (priv->css_provider),
@@ -1236,7 +1288,7 @@ gtk_source_map_init (GtkSourceMap *map)
 	completion = gtk_source_view_get_completion (GTK_SOURCE_VIEW (map));
 	gtk_source_completion_block_interactive (completion);
 
-	gtk_source_map_set_font_name (map, "BuilderBlocks 2");
+	gtk_source_map_set_font_name (map, "BuilderBlocks");
 
 	drag = gtk_gesture_drag_new ();
 	gtk_event_controller_set_propagation_phase (GTK_EVENT_CONTROLLER (drag),
@@ -1276,11 +1328,9 @@ gtk_source_map_init (GtkSourceMap *map)
 /**
  * gtk_source_map_new:
  *
- * Creates a new #GtkSourceMap.
+ * Creates a new `GtkSourceMap`.
  *
  * Returns: a new #GtkSourceMap.
- *
- * Since: 3.18
  */
 GtkWidget *
 gtk_source_map_new (void)
@@ -1294,8 +1344,6 @@ gtk_source_map_new (void)
  * @view: a #GtkSourceView
  *
  * Sets the view that @map will be doing the mapping to.
- *
- * Since: 3.18
  */
 void
 gtk_source_map_set_view (GtkSourceMap  *map,
@@ -1330,11 +1378,9 @@ gtk_source_map_set_view (GtkSourceMap  *map,
  * gtk_source_map_get_view:
  * @map: a #GtkSourceMap.
  *
- * Gets the #GtkSourceMap:view property, which is the view this widget is mapping.
+ * Gets the [property@Map:view] property, which is the view this widget is mapping.
  *
  * Returns: (transfer none) (nullable): a #GtkSourceView or %NULL.
- *
- * Since: 3.18
  */
 GtkSourceView *
 gtk_source_map_get_view (GtkSourceMap *map)
