@@ -255,15 +255,9 @@ elements_end_element (GMarkupParseContext  *context,
 
 			for (guint i = 0; state->languages[i]; i++)
 			{
-				char *stripped = g_strstrip (g_strdup (state->languages[i]));
+				info.language = _gtk_source_snippet_manager_intern (state->manager, state->languages[i]);
 
-				if (stripped != NULL && stripped[0] != 0)
-				{
-					info.language = _gtk_source_snippet_manager_intern (state->manager, stripped);
-					gtk_source_snippet_bundle_add (state->self, &info);
-				}
-
-				g_free (stripped);
+				gtk_source_snippet_bundle_add (state->self, &info);
 			}
 
 		}
@@ -439,17 +433,11 @@ gtk_source_snippet_bundle_parse (GtkSourceSnippetBundle  *self,
 	gchar *contents = NULL;
 	gsize length = 0;
 	gboolean ret = FALSE;
-	GFile *file;
 
 	g_assert (GTK_SOURCE_IS_SNIPPET_BUNDLE (self));
 	g_assert (path != NULL);
 
-	if (g_str_has_prefix (path, "resource://"))
-		file = g_file_new_for_uri (path);
-	else
-		file = g_file_new_for_path (path);
-
-	if (g_file_load_contents (file, NULL, &contents, &length, NULL, NULL))
+	if (g_file_get_contents (path, &contents, &length, NULL))
 	{
 		GMarkupParseContext *context;
 		ParseState state = {0};
@@ -488,8 +476,6 @@ gtk_source_snippet_bundle_parse (GtkSourceSnippetBundle  *self,
 #endif
 	}
 
-	g_object_unref (file);
-
 	return ret;
 }
 
@@ -639,16 +625,6 @@ create_snippet_from_info (GtkSourceSnippetBundle     *self,
 	return g_steal_pointer (&snippet);
 }
 
-GtkSourceSnippet *
-_gtk_source_snippet_bundle_create_snippet (GtkSourceSnippetBundle     *self,
-                                           const GtkSourceSnippetInfo *info)
-{
-	g_return_val_if_fail (GTK_SOURCE_IS_SNIPPET_BUNDLE (self), NULL);
-	g_return_val_if_fail (info != NULL, NULL);
-
-	return create_snippet_from_info (self, info);
-}
-
 static gboolean
 info_matches (const GtkSourceSnippetInfo *info,
               const gchar                *group,
@@ -725,7 +701,7 @@ _gtk_source_snippet_bundle_list_matching (GtkSourceSnippetBundle *self,
                                           const gchar            *trigger_prefix)
 {
 	GtkSourceSnippetBundle *ret;
-	const char *last = NULL;
+	const gchar *last = NULL;
 
 	g_return_val_if_fail (GTK_SOURCE_IS_SNIPPET_BUNDLE (self), NULL);
 
@@ -760,18 +736,6 @@ gtk_source_snippet_bundle_get_n_items (GListModel *model)
 	return GTK_SOURCE_SNIPPET_BUNDLE (model)->infos->len;
 }
 
-GtkSourceSnippetInfo *
-_gtk_source_snippet_bundle_get_info (GtkSourceSnippetBundle *self,
-                                     guint                   position)
-{
-	if (position >= self->infos->len)
-	{
-		return NULL;
-	}
-
-	return &g_array_index (self->infos, GtkSourceSnippetInfo, position);
-}
-
 static gpointer
 gtk_source_snippet_bundle_get_item (GListModel *model,
                                     guint       position)
