@@ -32,22 +32,21 @@
 #include "gtksourcelanguage-private.h"
 
 /**
- * SECTION:stylescheme
- * @Short_description: Controls the appearance of GtkSourceView
- * @Title: GtkSourceStyleScheme
- * @See_also: #GtkSourceStyle, #GtkSourceStyleSchemeManager
+ * GtkSourceStyleScheme:
+ *
+ * Controls the appearance of [class@View].
  *
  * #GtkSourceStyleScheme contains all the text styles to be used in
- * #GtkSourceView and #GtkSourceBuffer. For instance, it contains text styles
+ * [class@View] and [class@Buffer]. For instance, it contains text styles
  * for syntax highlighting, it may contain foreground and background color for
  * non-highlighted text, color for the line numbers, current line highlighting,
  * bracket matching, etc.
  *
  * Style schemes are stored in XML files. The format of a scheme file is
- * documented in the [style scheme reference][style-reference].
+ * documented in the [style scheme reference](./style-reference.html).
  *
  * The two style schemes with IDs "classic" and "tango" follow more closely the
- * GTK+ theme (for example for the background color).
+ * GTK theme (for example for the background color).
  */
 
 #define STYLE_TEXT			"text"
@@ -64,7 +63,6 @@
 #define STYLE_RIGHT_MARGIN		"right-margin"
 #define STYLE_DRAW_SPACES		"draw-spaces"
 #define STYLE_SNIPPET_FOCUS		"snippet-focus"
-#define STYLE_BACKGROUND		"background"
 #define STYLE_BACKGROUND_PATTERN	"background-pattern"
 
 #define STYLE_SCHEME_VERSION		"1.0"
@@ -94,6 +92,7 @@ struct _GtkSourceStyleScheme
 	GHashTable *defined_styles;
 	GHashTable *style_cache;
 	GHashTable *named_colors;
+	GHashTable *metadata;
 
 	GtkCssProvider *css_provider;
 };
@@ -105,23 +104,10 @@ gtk_source_style_scheme_dispose (GObject *object)
 {
 	GtkSourceStyleScheme *scheme = GTK_SOURCE_STYLE_SCHEME (object);
 
-	if (scheme->named_colors != NULL)
-	{
-		g_hash_table_unref (scheme->named_colors);
-		scheme->named_colors = NULL;
-	}
-
-	if (scheme->style_cache != NULL)
-	{
-		g_hash_table_unref (scheme->style_cache);
-		scheme->style_cache = NULL;
-	}
-
-	if (scheme->defined_styles != NULL)
-	{
-		g_hash_table_unref (scheme->defined_styles);
-		scheme->defined_styles = NULL;
-	}
+	g_clear_pointer (&scheme->named_colors, g_hash_table_unref);
+	g_clear_pointer (&scheme->style_cache, g_hash_table_unref);
+	g_clear_pointer (&scheme->defined_styles, g_hash_table_unref);
+	g_clear_pointer (&scheme->metadata, g_hash_table_unref);
 
 	g_clear_object (&scheme->parent);
 	g_clear_object (&scheme->css_provider);
@@ -215,7 +201,7 @@ gtk_source_style_scheme_class_init (GtkSourceStyleSchemeClass *klass)
 	 * GtkSourceStyleScheme:id:
 	 *
 	 * Style scheme id, a unique string used to identify the style scheme
-	 * in #GtkSourceStyleSchemeManager.
+	 * in [class@StyleSchemeManager].
 	 */
 	g_object_class_install_property (object_class,
 					 PROP_ID,
@@ -296,8 +282,6 @@ gtk_source_style_scheme_init (GtkSourceStyleScheme *scheme)
  * @scheme: a #GtkSourceStyleScheme.
  *
  * Returns: @scheme id.
- *
- * Since: 2.0
  */
 const gchar *
 gtk_source_style_scheme_get_id (GtkSourceStyleScheme *scheme)
@@ -313,8 +297,6 @@ gtk_source_style_scheme_get_id (GtkSourceStyleScheme *scheme)
  * @scheme: a #GtkSourceStyleScheme.
  *
  * Returns: @scheme name.
- *
- * Since: 2.0
  */
 const gchar *
 gtk_source_style_scheme_get_name (GtkSourceStyleScheme *scheme)
@@ -330,8 +312,6 @@ gtk_source_style_scheme_get_name (GtkSourceStyleScheme *scheme)
  * @scheme: a #GtkSourceStyleScheme.
  *
  * Returns: (nullable): @scheme description (if defined), or %NULL.
- *
- * Since: 2.0
  */
 const gchar *
 gtk_source_style_scheme_get_description (GtkSourceStyleScheme *scheme)
@@ -348,8 +328,6 @@ gtk_source_style_scheme_get_description (GtkSourceStyleScheme *scheme)
  * Returns: (nullable) (array zero-terminated=1) (transfer none): a
  * %NULL-terminated array containing the @scheme authors or %NULL if
  * no author is specified by the style scheme.
- *
- * Since: 2.0
  */
 const gchar * const *
 gtk_source_style_scheme_get_authors (GtkSourceStyleScheme *scheme)
@@ -370,8 +348,6 @@ gtk_source_style_scheme_get_authors (GtkSourceStyleScheme *scheme)
  *
  * Returns: (nullable): @scheme file name if the scheme was created
  * parsing a style scheme file or %NULL in the other cases.
- *
- * Since: 2.0
  */
 const gchar *
 gtk_source_style_scheme_get_filename (GtkSourceStyleScheme *scheme)
@@ -413,8 +389,6 @@ color_parse (const gchar *color,
  * Returned value is actual color string suitable for gdk_rgba_parse().
  * It may be @name or part of @name so copy it or something, if you need
  * it to stay around.
- *
- * Since: 2.0
  */
 static const gchar *
 get_color_by_name (GtkSourceStyleScheme *scheme,
@@ -544,8 +518,6 @@ gtk_source_style_scheme_get_style_internal (GtkSourceStyleScheme *scheme,
  * Returns: (nullable) (transfer none): style which corresponds to @style_id in
  * the @scheme, or %NULL when no style with this name found.  It is owned by
  * @scheme and may not be unref'ed.
- *
- * Since: 2.0
  */
 /*
  * It's a little weird because we have named colors: styles loaded from
@@ -668,8 +640,8 @@ get_color (GtkSourceStyle *style,
  * Returns TRUE if the style for current-line is set in the scheme
  */
 gboolean
-_gtk_source_style_scheme_get_current_line_color (GtkSourceStyleScheme *scheme,
-                                                 GdkRGBA              *color)
+_gtk_source_style_scheme_get_current_line_background_color (GtkSourceStyleScheme *scheme,
+							    GdkRGBA              *color)
 {
 	GtkSourceStyle *style;
 
@@ -692,6 +664,40 @@ _gtk_source_style_scheme_get_current_line_number_color (GtkSourceStyleScheme *sc
 
 	style = gtk_source_style_scheme_get_style (scheme, STYLE_CURRENT_LINE_NUMBER);
 
+	return get_color (style, TRUE, color);
+}
+
+gboolean
+_gtk_source_style_scheme_get_current_line_number_bold (GtkSourceStyleScheme *scheme)
+{
+	GtkSourceStyle *style;
+	gboolean bold_set = FALSE;
+	gboolean bold = FALSE;
+
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme), FALSE);
+
+	if ((style = gtk_source_style_scheme_get_style (scheme, STYLE_CURRENT_LINE_NUMBER)))
+	{
+		g_object_get (style,
+		              "bold-set", &bold_set,
+		              "bold", &bold,
+		              NULL);
+	}
+
+	return !bold_set || bold;
+}
+
+gboolean
+_gtk_source_style_scheme_get_current_line_number_background_color (GtkSourceStyleScheme *scheme,
+                                                                   GdkRGBA              *color)
+{
+	GtkSourceStyle *style;
+
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme), FALSE);
+	g_return_val_if_fail (color != NULL, FALSE);
+
+	style = gtk_source_style_scheme_get_style (scheme, STYLE_CURRENT_LINE_NUMBER);
+
 	return get_color (style, FALSE, color);
 }
 
@@ -721,11 +727,25 @@ _gtk_source_style_scheme_get_background_color (GtkSourceStyleScheme *scheme,
 	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme), FALSE);
 	g_return_val_if_fail (color != NULL, FALSE);
 
-	style = gtk_source_style_scheme_get_style (scheme, STYLE_BACKGROUND);
+	style = gtk_source_style_scheme_get_style (scheme, STYLE_TEXT);
 
 	return get_color (style, FALSE, color);
 }
 
+gboolean
+_gtk_source_style_scheme_get_text_color (GtkSourceStyleScheme *scheme,
+                                         GdkRGBA              *color)
+{
+	GtkSourceStyle *style;
+
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme), FALSE);
+	g_return_val_if_fail (color != NULL, FALSE);
+
+	style = gtk_source_style_scheme_get_style (scheme, STYLE_TEXT);
+
+	return get_color (style, TRUE, color);
+}
+
 static void
 apply_css_style_cursors (GtkSourceStyleScheme *scheme,
                          GString              *css)
@@ -790,8 +810,6 @@ apply_css_style_cursors (GtkSourceStyleScheme *scheme,
  * @widget: (nullable): a #GtkWidget to apply styles to.
  *
  * Sets style colors from @scheme to the @widget.
- *
- * Since: 2.0
  */
 void
 _gtk_source_style_scheme_apply (GtkSourceStyleScheme *scheme,
@@ -819,8 +837,6 @@ _gtk_source_style_scheme_apply (GtkSourceStyleScheme *scheme,
  * @widget: (nullable): a (#GtkWidget to unapply styles to.
  *
  * Removes the styles from @scheme in the @widget.
- *
- * Since: 3.0
  */
 void
 _gtk_source_style_scheme_unapply (GtkSourceStyleScheme *scheme,
@@ -877,6 +893,43 @@ get_css_color_style (GtkSourceStyle *style,
 	}
 }
 
+static void
+fix_broken_selection (char **bg_out,
+		      char **text_out)
+{
+	char *bg = *bg_out;
+	char *text = *text_out;
+	char *tmp = NULL;
+	const char *space;
+	const char *semi;
+	GdkRGBA rgba;
+
+	/* If there is no foreground and the background is solid, we must
+	 * alter it to be transparent or some systems will not see anything
+	 * (such as those in libadwaita).
+	 */
+
+	if ((space = strchr (bg, ' ')) &&
+	    (semi = strchr (space, ';')) &&
+	    (tmp = g_strndup (space + 1, semi - space - 1)) &&
+	    gdk_rgba_parse (&rgba, tmp) &&
+	    rgba.alpha >= 1.0)
+	{
+		char *new_bg;
+		rgba.alpha = .3;
+		new_bg = gdk_rgba_to_string (&rgba);
+		g_free (bg);
+		text = g_strdup ("color: rgba(0,0,0,0);");
+		bg = g_strdup_printf ("background-color: %s;", new_bg);
+		g_free (new_bg);
+	}
+
+	g_free (tmp);
+
+	*bg_out = bg;
+	*text_out = text;
+}
+
 static void
 append_css_style (GString        *string,
                   GtkSourceStyle *style,
@@ -890,8 +943,12 @@ append_css_style (GString        *string,
 		"}\n";
 
 	get_css_color_style (style, &bg, &text);
+
 	if (bg || text)
 	{
+		if (bg && !text && g_str_has_suffix (selector, " selection"))
+			fix_broken_selection (&bg, &text);
+
 		g_string_append_printf (string, css_style, selector,
 		                        bg != NULL ? bg : "",
 		                        text != NULL ? text : "");
@@ -971,13 +1028,35 @@ generate_css_style (GtkSourceStyleScheme *scheme)
 }
 
 static gboolean
-parse_bool (char *value)
+parse_bool (const char *value)
 {
 	return (g_ascii_strcasecmp (value, "true") == 0 ||
 	        g_ascii_strcasecmp (value, "yes") == 0 ||
 	        g_ascii_strcasecmp (value, "1") == 0);
 }
 
+static gboolean
+parse_int (int        *out_value,
+           const char *str)
+{
+	gint64 v;
+
+	if (str == NULL)
+		return FALSE;
+
+	if (str[0] < '0' || str[0] > '9')
+		return FALSE;
+
+	v = g_ascii_strtoll (str, NULL, 10);
+
+	if (v < G_MININT || v > G_MAXINT)
+		return FALSE;
+
+	*out_value = v;
+
+	return TRUE;
+}
+
 static void
 get_bool (xmlNode    *node,
           const char *propname,
@@ -1016,6 +1095,7 @@ parse_style (GtkSourceStyleScheme  *scheme,
 	xmlChar *underline = NULL;
 	xmlChar *underline_color = NULL;
 	xmlChar *scale = NULL;
+	xmlChar *weight = NULL;
 	xmlChar *tmp;
 
 	tmp = xmlGetProp (node, BAD_CAST "name");
@@ -1054,6 +1134,7 @@ parse_style (GtkSourceStyleScheme  *scheme,
 	underline = xmlGetProp (node, BAD_CAST "underline");
 	underline_color = xmlGetProp (node, BAD_CAST "underline-color");
 	scale = xmlGetProp (node, BAD_CAST "scale");
+	weight = xmlGetProp (node, BAD_CAST "weight");
 
 	if (use_style)
 	{
@@ -1063,7 +1144,8 @@ parse_style (GtkSourceStyleScheme  *scheme,
 		    mask != 0 ||
 		    underline != NULL ||
 		    underline_color != NULL ||
-		    scale != NULL)
+		    scale != NULL ||
+		    weight != NULL)
 		{
 			g_set_error (error, ERROR_QUARK, 0,
 				     "in style '%s': style attributes used along with use-style",
@@ -1076,6 +1158,7 @@ parse_style (GtkSourceStyleScheme  *scheme,
 			xmlFree (underline);
 			xmlFree (underline_color);
 			xmlFree (scale);
+			xmlFree (weight);
 			return FALSE;
 		}
 
@@ -1152,6 +1235,45 @@ parse_style (GtkSourceStyleScheme  *scheme,
 			result->scale = g_intern_string ((char*) scale);
 			result->mask |= GTK_SOURCE_STYLE_USE_SCALE;
 		}
+
+		if (weight != NULL)
+		{
+			GEnumClass *enum_class;
+			GEnumValue *enum_value;
+			char *weight_lowercase;
+			int v;
+
+			enum_class = G_ENUM_CLASS (g_type_class_ref (PANGO_TYPE_WEIGHT));
+
+			weight_lowercase = g_ascii_strdown ((char*) weight, -1);
+			enum_value = g_enum_get_value_by_nick (enum_class, weight_lowercase);
+			g_free (weight_lowercase);
+
+			if (enum_value != NULL)
+			{
+				result->weight = enum_value->value;
+				result->mask |= GTK_SOURCE_STYLE_USE_WEIGHT;
+				result->mask &= ~GTK_SOURCE_STYLE_USE_BOLD;
+			}
+			else if (parse_int (&v, weight_lowercase))
+			{
+				result->weight = v;
+				result->mask |= GTK_SOURCE_STYLE_USE_WEIGHT;
+				result->mask &= ~GTK_SOURCE_STYLE_USE_BOLD;
+			}
+			else
+			{
+				static gboolean has_warned;
+
+				if (!has_warned)
+				{
+					g_warning ("Failed to parse style attribute weight=\"%s\"", weight);
+					has_warned = TRUE;
+				}
+			}
+
+			g_type_class_unref (enum_class);
+		}
 	}
 
 	*style_p = result;
@@ -1163,6 +1285,7 @@ parse_style (GtkSourceStyleScheme  *scheme,
 	xmlFree (underline);
 	xmlFree (underline_color);
 	xmlFree (scale);
+	xmlFree (weight);
 
 	return TRUE;
 }
@@ -1242,6 +1365,38 @@ parse_style_scheme_child (GtkSourceStyleScheme  *scheme,
 		scheme->description = g_strdup (_((char*) tmp));
 		xmlFree (tmp);
 	}
+	else if (strcmp ((char*) node->name, "metadata") == 0)
+	{
+		for (xmlNode *child = node->children; child != NULL; child = child->next)
+		{
+			if (strcmp ((char*) child->name, "property") == 0)
+			{
+				xmlChar *name;
+				xmlChar *content;
+
+				name = xmlGetProp (child, BAD_CAST "name");
+				content = xmlNodeGetContent (child);
+
+				if (name != NULL && content != NULL)
+				{
+					if (scheme->metadata == NULL)
+					{
+						scheme->metadata = g_hash_table_new_full (g_str_hash,
+						                                          g_str_equal,
+						                                          g_free,
+						                                          g_free);
+					}
+
+					g_hash_table_insert (scheme->metadata,
+					                     g_strdup ((char *)name),
+					                     g_strdup ((char *)content));
+				}
+
+				xmlFree (name);
+				xmlFree (content);
+			}
+		}
+	}
 	else
 	{
 		g_set_error (error, ERROR_QUARK, 0, "unknown node '%s'", node->name);
@@ -1323,8 +1478,6 @@ parse_style_scheme_element (GtkSourceStyleScheme  *scheme,
  *
  * Returns: (nullable): new #GtkSourceStyleScheme created from file,
  * or %NULL on error.
- *
- * Since: 2.0
  */
 GtkSourceStyleScheme *
 _gtk_source_style_scheme_new_from_file (const gchar *filename)
@@ -1402,8 +1555,6 @@ _gtk_source_style_scheme_new_from_file (const gchar *filename)
  * @scheme: a #GtkSourceStyleScheme.
  *
  * Returns: (nullable): parent style scheme id or %NULL.
- *
- * Since: 2.0
  */
 const gchar *
 _gtk_source_style_scheme_get_parent_id (GtkSourceStyleScheme *scheme)
@@ -1421,8 +1572,6 @@ _gtk_source_style_scheme_get_parent_id (GtkSourceStyleScheme *scheme)
  * Sets @parent_scheme as parent scheme for @scheme, @scheme will
  * look for styles in @parent_scheme if it doesn't have style set
  * for given name.
- *
- * Since: 2.0
  */
 void
 _gtk_source_style_scheme_set_parent (GtkSourceStyleScheme *scheme,
@@ -1455,8 +1604,6 @@ _gtk_source_style_scheme_set_parent (GtkSourceStyleScheme *scheme,
  *
  * Returns: default style scheme to be used when user didn't set
  * style scheme explicitly.
- *
- * Since: 2.0
  */
 GtkSourceStyleScheme *
 _gtk_source_style_scheme_get_default (void)
@@ -1468,3 +1615,31 @@ _gtk_source_style_scheme_get_default (void)
 	return gtk_source_style_scheme_manager_get_scheme (manager,
 							   DEFAULT_STYLE_SCHEME);
 }
+
+/**
+ * gtk_source_style_scheme_get_metadata:
+ * @scheme: a #GtkSourceStyleScheme.
+ * @name: metadata property name.
+ *
+ * Gets a metadata property from the style scheme.
+ *
+ * Returns: (nullable) (transfer none): value of property @name stored in
+ *   the metadata of @scheme or %NULL if @scheme does not contain the
+ *   specified metadata property.
+ *
+ * Since: 5.4
+ */
+const char *
+gtk_source_style_scheme_get_metadata (GtkSourceStyleScheme *scheme,
+                                      const char           *name)
+{
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+
+	if (scheme->metadata == NULL)
+	{
+		return NULL;
+	}
+
+	return g_hash_table_lookup (scheme->metadata, name);
+}
