@@ -89,5 +89,8 @@ gboolean _gtk_source_view_get_current_line_background        (GtkSourceView *vie
                                                               GdkRGBA       *rgba);
 gboolean _gtk_source_view_get_current_line_number_background (GtkSourceView *view,
                                                               GdkRGBA       *rgba);
+gboolean _gtk_source_view_get_current_line_number_color      (GtkSourceView *view,
+                                                              GdkRGBA       *rgba);
+gboolean _gtk_source_view_get_current_line_number_bold       (GtkSourceView *view);
 
 G_END_DECLS
