@@ -999,9 +999,33 @@ key_handler_split (GtkSourceVimNormal *self,
                    GdkModifierType     mods,
                    const char         *string)
 {
+	GtkSourceVimState *root;
+
 	g_assert (GTK_SOURCE_IS_VIM_NORMAL (self));
 
-	return TRUE;
+	switch (keyval)
+	{
+	case GDK_KEY_c:
+	case GDK_KEY_v:
+	case GDK_KEY_s:
+	case GDK_KEY_w:
+	case GDK_KEY_h:
+	case GDK_KEY_l:
+	case GDK_KEY_j:
+	case GDK_KEY_k:
+		if ((root = gtk_source_vim_state_get_root (GTK_SOURCE_VIM_STATE (self))) &&
+		    GTK_SOURCE_IS_VIM (root))
+		{
+			gtk_source_vim_emit_execute_command (GTK_SOURCE_VIM (root), self->command_text->str);
+			gtk_source_vim_normal_clear (self);
+			return TRUE;
+		}
+
+		G_GNUC_FALLTHROUGH;
+
+	default:
+		return gtk_source_vim_normal_bail (self);
+	}
 }
 
 static gboolean
@@ -1134,7 +1158,7 @@ key_handler_initial (GtkSourceVimNormal *self,
 
 			case GDK_KEY_w:
 				self->handler = key_handler_split;
-				break;
+				return TRUE;
 
 			case GDK_KEY_r:
 				self->handler = key_handler_command;
